@@ -3,7 +3,7 @@ xlwings - Make Excel fly with Python!
 
 Homepage and documentation: https://www.xlwings.org
 
-Copyright (C) 2014-present, Zoomer Analytics LLC.
+Copyright (C) 2014-present, Zoomer Analytics GmbH.
 All rights reserved.
 
 License: BSD 3-clause (see LICENSE.txt for details)
@@ -12,7 +12,6 @@ import os
 import sys
 import re
 import numbers
-import inspect
 
 from . import xlplatform, ShapeAlreadyExists
 from .utils import VersionNumber
@@ -326,6 +325,16 @@ class App:
     def display_alerts(self, value):
         self.impl.display_alerts = value
 
+    @property
+    def startup_path(self):
+        """
+        Returns the path to ``XLSTART`` which is where the xlwings add-in gets
+        copied to by doing ``xlwings addin install``.
+
+        .. versionadded:: 0.19.4
+        """
+        return self.impl.startup_path
+
     @property
     def calculation(self):
         """
@@ -390,18 +399,6 @@ class App:
         """
         return Range(impl=self.impl.range(cell1, cell2))
 
-    def __repr__(self):
-        return "<Excel App %s>" % self.pid
-
-    def __eq__(self, other):
-        return type(other) is App and other.pid == self.pid
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
-    def __hash__(self):
-        return hash(self.pid)
-
     def macro(self, name):
         """
         Runs a Sub or Function in Excel VBA that are not part of a specific workbook but e.g. are part of an add-in.
@@ -434,6 +431,18 @@ class App:
         """
         return Macro(self, name)
 
+    def __repr__(self):
+        return "<Excel App %s>" % self.pid
+
+    def __eq__(self, other):
+        return type(other) is App and other.pid == self.pid
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+    def __hash__(self):
+        return hash(self.pid)
+
 
 class Book:
     """
@@ -555,9 +564,8 @@ class Book:
     def caller(cls):
         """
         References the calling book when the Python function is called from Excel via ``RunPython``.
-        Pack it into the function being called from Excel, e.g.:
+        Pack it into the function being called from Excel, e.g.::
 
-        .. code-block:: python
             import xlwings as xw
 
              def my_macro():
@@ -1186,6 +1194,15 @@ class Range:
     def formula(self, value):
         self.impl.formula = value
 
+    @property
+    def formula2(self):
+        """Gets or sets the formula2 for the given Range."""
+        return self.impl.formula2
+
+    @formula2.setter
+    def formula2(self, value):
+        self.impl.formula2 = value
+
     @property
     def formula_array(self):
         """
@@ -2018,6 +2035,15 @@ class Shape:
 
         self.impl = impl
 
+    @property
+    def api(self):
+        """
+        Returns the native object (``pywin32`` or ``appscript`` obj) of the engine being used.
+
+        .. versionadded:: 0.19.2
+        """
+        return self.impl.api
+
     @property
     def name(self):
         """
@@ -2108,6 +2134,40 @@ class Shape:
         """
         self.impl.activate()
 
+    def scale_height(self, factor, relative_to_original_size=False, scale='scale_from_top_left'):
+        """
+        factor : float
+            For example 1.5 to scale it up to 150%
+
+        relative_to_original_size : bool, optional
+            If ``False``, it scales relative to current height (default).
+            For ``True`` must be a picture or OLE object.
+
+        scale : str, optional
+            One of ``scale_from_top_left`` (default), ``scale_from_bottom_right``, ``scale_from_middle``
+
+        .. versionadded:: 0.19.2
+        """
+        self.impl.scale_height(factor=factor, relative_to_original_size=relative_to_original_size,
+                               scale=scale)
+
+    def scale_width(self, factor, relative_to_original_size=False, scale='scale_from_top_left'):
+        """
+        factor : float
+            For example 1.5 to scale it up to 150%
+
+        relative_to_original_size : bool, optional
+            If ``False``, it scales relative to current width (default).
+            For ``True`` must be a picture or OLE object.
+
+        scale : str, optional
+            One of ``scale_from_top_left`` (default), ``scale_from_bottom_right``, ``scale_from_middle``
+
+        .. versionadded:: 0.19.2
+        """
+        self.impl.scale_width(factor=factor, relative_to_original_size=relative_to_original_size,
+                              scale=scale)
+
     @property
     def parent(self):
         """
@@ -2484,7 +2544,7 @@ class Picture:
         name = self.name
 
         # todo: link_to_file, save_with_document
-        picture = self.parent.pictures.add(filename, left=left, top=top, width=width, height=height)
+        picture = self.parent.pictures.add(filename, left=left, top=top, width=width, height=height, scale=False)
         self.delete()
 
         picture.name = name
@@ -2509,7 +2569,8 @@ class Pictures(Collection):
     def parent(self):
         return Sheet(impl=self.impl.parent)
 
-    def add(self, image, link_to_file=False, save_with_document=True, left=0, top=0, width=None, height=None, name=None, update=False):
+    def add(self, image, link_to_file=False, save_with_document=True, left=0, top=0, width=None, height=None,
+            name=None, update=False, scale=1):
         """
         Adds a picture to the specified sheet.
 
@@ -2600,6 +2661,11 @@ class Pictures(Collection):
             filename, link_to_file, save_with_document, left, top, width, height
         ))
 
+        if scale:
+            # By default, Excel usually distorts the width/height. This corrects it.
+            self.parent.shapes[picture.name].scale_width(factor=scale, relative_to_original_size=True)
+            self.parent.shapes[picture.name].scale_height(factor=scale, relative_to_original_size=True)
+
         if name is not None:
             picture.name = name
         return picture
